#!/bin/bash
#
# source: ftp://ftp.gimp.org/pub/gimp/v2.6/gimp-2.6.11.tar.bz2
#
# maintainer: gmg (monpontet@gmail.com)
#
#

# Set initial variables:

soft='gimp'
softversion='2.6.11'
packageversion='70.2'

arch='i486'
cpu='i686'

buildir=$(pwd)
srcpkg="$buildir/$soft-$softversion.tar.bz2"
src="$buildir/$soft-$softversion"
package="$soft-$softversion-$arch-$packageversion"
dest="$buildir/$package"

cd $buildir
rm -rf $src
tar -xvjf $srcpkg
rm -f $dest.tgz
rm -rf $dest

cd $src
chown -R root:root .
find . \
  \( -perm 777 -o -perm 775 -o -perm 711 -o -perm 555 -o -perm 511 \) \
  -exec chmod 755 {} \; -o \
  \( -perm 666 -o -perm 664 -o -perm 600 -o -perm 444 -o -perm 440 -o -perm 400 \) \
  -exec chmod 644 {} \;

export CFLAGS="-O2 -march=$arch -mtune=$cpu"
export CXXFLAGS="-O2 -march=$arch -mtune=$cpu"
./configure \
  --prefix=/usr \
  --sysconfdir=/etc \
  --localstatedir=/var/lib \
  --mandir=/usr/man \
  --disable-static \
  --enable-gimp-remote \
  --without-webkit \
  --without-gnomevfs \
  --without-hal \
  --enable-introspection=no \
  --with-html-dir=/usr/doc/$soft-$softversion

make -j6
mkdir -p $dest/usr/share/applications $dest/usr/share/application-registry
make install DESTDIR=$dest

# Add a manpage symlink for POLA-compliance
( cd $dest/usr/man/man1 ; ln -sf gimptool-2.?.1 gimptool.1 )

( cd $dest/usr/man
  find . -type f -exec gzip -9 {} \;
  for i in $(find . -type l) ; do ln -s $(readlink $i).gz $i.gz ; rm $i ; done
)

cp -a \
  AUTHORS COPYING HACKING INSTALL LICENSE NEWS README* docs/Wilber* \
  $dest/usr/doc/$soft-$softversion

find $dest | xargs file | grep -e "executable" -e "shared object" | grep ELF \
  | cut -f 1 -d : | xargs strip --strip-unneeded 2> /dev/null

mkdir -p $dest/install
cat << EODESC > $dest/install/slack-desc
# HOW TO EDIT THIS FILE:
# The "handy ruler" below makes it easier to edit a package description.  Line
# up the first '|' above the ':' following the base package name, and the '|'
# on the right side marks the last column you can put a character in.  You must
# make exactly 11 lines for the formatting to be correct.  It's also
# customary to leave one space after the ':'.

    |-----handy-ruler--------------------------------------------------------|
gimp: gimp - The GNU Image Manipulation Program
gimp:
gimp: The GIMP is a powerful tool for the preparation and manipulation of
gimp: digital images.The GIMP provides the user with a wide variety of
gimp: image manipulation, painting, processing, and rendering tools.  The
gimp: GIMP's open design and extensible architecture make for a very
gimp: powerful end product for photo and image retouching, web graphics
gimp: design, or digital illustration.
gimp:
gimp:
gimp:
EODESC

#----------------Change the default gimp-splash and theme

cd $dest/usr/share/$soft/2.0/images
mv gimp-splash.png gimp-orig-splash.png
cp $buildir/gimp-splash.png $dest/usr/share/$soft/2.0/images

mkdir -p $dest/usr/src/$soft-$softversion
cp $buildir/build-$soft.sh $dest/usr/src/$soft-$softversion

# Packaging
cd $dest
makepkg -l y -c n $dest.txz

cd $buildir
md5sum $package.txz > $package.md5